//----------------------------------------------------------------------------
//
// File: ossimTieMeasurementGeneratorInterface.h
//
// License:  LGPL
// 
// See LICENSE.txt file in the top level directory for more details.
//
// Author:  David hicks
//
// Description: OSSIM interface for tie measurement generator plugin.
//----------------------------------------------------------------------------
// $Id

#ifndef ossimTieMeasurementGeneratorInterface_HEADER
#define ossimTieMeasurementGeneratorInterface_HEADER 1

#include <ossim/base/ossimConstants.h>
#include <ossim/base/ossimDpt.h>
#include <iosfwd>


class ossimImageSource;

class ossimTieMeasurementGeneratorInterface
{
public:

   /** @brief Virtual destructor defined to squash compiler errors. */
   virtual ~ossimTieMeasurementGeneratorInterface(){}

   virtual bool init(std::vector<ossimImageSource*> src, std::ostream& report = std::cout) = 0;

   virtual bool run() = 0;

   virtual void summarizeRun() const = 0;
   
   virtual bool setPatchSize(const int& patchDim) = 0;
   virtual bool setPatchSize(const ossimIpt& patchDimensions) = 0;
   virtual ossimIpt getPatchSize() const = 0;
   virtual bool setGridSize(const ossimIpt& gridDimensions) = 0;
   virtual ossimIpt getGridSize() const = 0;

   virtual bool setBox(const ossimDpt& startPt, const ossimDpt& stopPt, const ossim_uint32& index) = 0;
   virtual bool isValidCollectionBox() const = 0;

   virtual bool setMaxMatches(const int& maxMatches) = 0;


   // Set the feature detector
   virtual bool setFeatureDetector(const ossimString& name) = 0;
   virtual ossimString getFeatureDetector() const  = 0;
   
   // Set the descriptor-extractor
   virtual bool setDescriptorExtractor(const ossimString& name) = 0;
   virtual ossimString getDescriptorExtractor() const  = 0;
   
   // Set the matcher
   virtual bool setDescriptorMatcher(const ossimString& name) = 0;
   virtual ossimString getDescriptorMatcher() const  = 0;
   
   // Measured point access
   virtual int numMeasurements() const  = 0;
   virtual ossimDpt pointIndexedAt(const ossim_uint32 imgIdx,
                                   const ossim_uint32 measIdx) = 0;

   virtual void closeCvWindow() = 0;
};

#endif /* #ifndef ossimTieMeasurementGeneratorInterface_HEADER */
